@@ -1,6 +1,6 @@
 __author__ = 'nmaric'
 
-from infobip_api_python_client.util.configuration import Configuration
+from infobip.util.configuration import Configuration
 
 infobip_base_url = "https://api.infobip.com"
 infobip_username = "username"
